@@ -1,11 +1,13 @@
 package Text::FindIndent;
+# -*- mode: Perl -*-
+# Emacs mode is necessary for https://github.com/github/linguist/issues/2458
 
 use 5.00503;
 use strict;
 
 use vars qw{$VERSION};
 BEGIN {
-  $VERSION = '0.10';
+  $VERSION = '0.11';
 }
 
 use constant MAX_LINES => 500;
@@ -119,7 +121,7 @@ sub parse {
       }
       $next_line_braces_pos_plus_1=0;
     } else {
-      if ($rest=~/=> {$/) { #handle case where hash keys and values are indented by braces pos + 1
+      if ($rest =~ /=> \{$/) { #handle case where hash keys and values are indented by braces pos + 1
         $next_line_braces_pos_plus_1=_length_with_tabs_converted($ws)+length($rest);
       }
     }
@@ -223,7 +225,7 @@ sub _length_with_tabs_converted {
     my $str=shift;
     my $tablen=shift || 8;
     $str =~ s/( +)$//;
-    my $trailing_spaces = $1||0;
+    my $trailing_spaces = $1||'';
     $str =~ s/ +//g; #  assume the spaces are all contained in tabs!
     return length($str)*$tablen+length($trailing_spaces);
 }
@@ -239,10 +241,7 @@ sub _grok_indent_diff {
     $indentdiffs->{"t8"}++; # we can't infer what a tab means. Or rather, we need smarter code to do it
   }
   else { # mixed!
-    $diff =~ s/( +)$//;
-    my $trailing_spaces = $1||0;
-    $diff =~ s/ +//g; #  assume the spaces are all contained in tabs!
-    $indentdiffs->{"m" . (length($diff)*8+length($trailing_spaces))}++;
+    $indentdiffs->{"m" . _length_with_tabs_converted($diff)}++;
   }
 }
 
@@ -256,10 +255,7 @@ sub _analyse_indent_diff {
     return "t8"; # we can't infer what a tab means. Or rather, we need smarter code to do it
   }
   else { # mixed!
-    $diff =~ s/( +)$//;
-    my $trailing_spaces = $1||0;
-    $diff =~ s/ +//g; #  assume the spaces are all contained in tabs!
-    return "m" . (length($diff)*8+length($trailing_spaces));
+    return "m" . _length_with_tabs_converted($diff);
   }
 }
 
